@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 our $DEV_SHM = "/dev/shm";
 our $DEBUG;
 *DEBUG = \$Forks::Queue::DEBUG;
@@ -29,6 +29,7 @@ sub new {
     $opts{limit} //= -1;
     $opts{on_limit} //= 'fail';
     $opts{style} //= 'fifo';
+    my $list = delete $opts{list};
 
     my $fh;
 
@@ -77,6 +78,13 @@ sub new {
             print $fh "\0" x ($self->{_header_size} - tell($fh));
         }
     }
+    if (defined($list)) {
+        if (ref($list) eq 'ARRAY') {
+            $self->push( @$list );
+        } else {
+            carp "Forks::Queue::new: 'list' option must be an array ref";
+        }
+    }
     return $self;
 }
 
@@ -105,7 +113,7 @@ Forks::Queue::Shmem - Forks::Queue implementation using shared memory
 
 =head1 VERSION
 
-0.01
+0.03
 
 =head1 DESCRIPTION
 
